| Title: | A Simple Wrapper of 'savvy-cli' Command |
|---|---|
| Description: | Generates the C and R wrappers for the Rust-powered R package using the savvy framework. |
| Authors: | Hiroaki Yutani [aut, cre] (ORCID: <https://orcid.org/0000-0002-3385-7233>) |
| Maintainer: | Hiroaki Yutani <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.5 |
| Built: | 2026-05-06 05:20:32 UTC |
| Source: | https://github.com/yutannihilation/savvy-helper-R-package |
savvy-cli extract-tests
Execute savvy-cli extract-tests
savvy_extract_tests(path = "./src/rust/")savvy_extract_tests(path = "./src/rust/")
path |
Path to the root of a Rust crate. |
Execute 'savvy-cli init“
savvy_init(path = ".", verbose = TRUE)savvy_init(path = ".", verbose = TRUE)
path |
Path to the root of an R package |
verbose |
If |
Compile Rust Code And Load
savvy_source( code, use_cache_dir = TRUE, env = parent.frame(), dependencies = list(), clean = NULL )savvy_source( code, use_cache_dir = TRUE, env = parent.frame(), dependencies = list(), clean = NULL )
code |
Rust code to compile. |
use_cache_dir |
If |
env |
The R environment where the R wrapping functions should be defined. |
dependencies |
List of dependencies. (e.g. |
clean |
If |
Execute 'savvy-cli update“
savvy_update(path = ".", verbose = TRUE)savvy_update(path = ".", verbose = TRUE)
path |
Path to the root of an R package |
verbose |
If |
Execute 'savvy-cli –version“
savvy_version()savvy_version()